pub struct IssuerData {
pub issuer: String,
pub algorithm: String,
}Expand description
this struct provides extra data stored in a cookie that’s used to identify which issuer provided the json web token so it can be properly constructed.
Fields
issuer: Stringalgorithm: StringTrait Implementations
Sourceimpl Clone for IssuerData
impl Clone for IssuerData
Sourcefn clone(&self) -> IssuerData
fn clone(&self) -> IssuerData
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for IssuerData
impl Debug for IssuerData
Sourceimpl<'de> Deserialize<'de> for IssuerData
impl<'de> Deserialize<'de> for IssuerData
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,