pub struct KeyID { /* private fields */ }Expand description
Identifier for a public key used in token validation.
Combines the issuer and algorithm to uniquely reference a key in a multi-issuer or multi-algorithm environment. This is not that same as what’s used within openidconnect crate, just used by this crates validator.
Implementations